Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bool ¶
Bool is a custom type that embeds sql.NullBool.
func (Bool) MarshalJSON ¶
MarshalJSON uses the Bool custom type and implements the json.Marshaler interface.
type Byte ¶
Byte is a custom type that embeds sql.NullByte.
func (Byte) MarshalJSON ¶
MarshalJSON uses the Byte custom type and implements the json.Marshaler interface.
type Float64 ¶
type Float64 struct {
sql.NullFloat64
}
Float64 is a custom type that embeds sql.NullFloat64
func (Float64) MarshalJSON ¶
MarshalJSON uses the Float64 custom type and implements the json.Marshaler interface.
type Int16 ¶
Int16 is a custom type that embeds sql.NullInt16.
func (Int16) MarshalJSON ¶
MarshalJSON uses the Int16 custom type and implements the json.Marshaler interface.
type Int32 ¶
Int32 is a custom type that embeds sql.NullInt32.
func (Int32) MarshalJSON ¶
MarshalJSON uses the Int32 custom type and implements the json.Marshaler interface.
type Int64 ¶
Int64 is a custom type that embeds sql.NullInt64.
func (Int64) MarshalJSON ¶
MarshalJSON uses the Int64 custom type and implements the json.Marshaler interface.
type String ¶
type String struct {
sql.NullString
}
String is a custom type that embeds sql.NullString.
func (String) MarshalJSON ¶
MarshalJSON uses the String custom type and implements the json.Marshaler interface.